paidiverpy.frontend.widgets
===========================

.. py:module:: paidiverpy.frontend.widgets

.. autoapi-nested-parse::

   
   __init__.py for frontend wigets module.
















   ..
       !! processed by numpydoc !!


Submodules
----------

.. toctree::
   :maxdepth: 1

   /api/paidiverpy/frontend/widgets/app/index
   /api/paidiverpy/frontend/widgets/config_general/index
   /api/paidiverpy/frontend/widgets/utils/index


